from __future__ import division

import logging
from datetime import datetime

import pytz

from .settings import LOGORAMA_TZ


class DateTimeFormatter(logging.Formatter):
    def formatTime(self, record, datefmt=None):
        ts = record.created * 1000000000
        dt = datetime.fromtimestamp(ts // 1000000000, tz=pytz.utc)
        dt = dt.astimezone(tz=pytz.timezone(LOGORAMA_TZ))
        s = "{}.{}".format(
            dt.strftime("%Y-%m-%d %H:%M:%S"), int(ts % 1000000000))
        return s


import sys
import logging

from colorama import init

from .formatter import DateTimeFormatter
from .stream import ColoredStreamHandler
from .settings import LOGORAMA_DEFAULT_LEVEL, LOGORAMA_DISABLE_COLORS, \
    LOGORAMA_DEFAULT_FORMAT


log_formatter = DateTimeFormatter(LOGORAMA_DEFAULT_FORMAT)

log_formatter.default_msec_format = "%s.%03d"
if LOGORAMA_DISABLE_COLORS:
    ch = logging.StreamHandler(sys.stdout)
else:
    ch = ColoredStreamHandler()
ch.setFormatter(log_formatter)
logger = logging.getLogger()
logger.addHandler(ch)
logger.setLevel(logging.INFO)

init(autoreset=True)


class BaseLogger(object):
    LOG_LEVEL = LOGORAMA_DEFAULT_LEVEL

    @property
    def logger(self):
        rv = logging.getLogger(
            name=self.__class__.__module__ + "." + self.__class__.__name__)
        rv.setLevel(self.LOG_LEVEL)
        return rv



import os
import logging
import colorama


LOGORAMA_DEFAULT_LEVEL = logging.INFO

LOGORAMA_DISABLE_COLORS = os.getenv("COLORAMA_DISABLE_COLORS")
LOGORAMA_DISABLE_COLORS = True if LOGORAMA_DISABLE_COLORS == "true" else False

LOGORAMA_TZ = "US/Central"

LOGORAMA_COLORS = {
    'WARNING': colorama.Fore.YELLOW,
    'INFO': colorama.Fore.GREEN,
    'DEBUG': colorama.Fore.CYAN,
    'ERROR': colorama.Fore.RED + colorama.Style.BRIGHT,
    'CRITICAL': colorama.Fore.WHITE + colorama.Back.RED
}

LOGORAMA_DEFAULT_FORMAT = '%(asctime)s - [%(levelname)s] - ' \
                          '{%(name)s:%(funcName)s:%(lineno)s} - %(message)s'



import logging
import colorama

from .settings import LOGORAMA_COLORS


class ColoredStreamHandler(logging.StreamHandler):
    def emit(self, record):
        message = self.format(record)
        self.stream.write(LOGORAMA_COLORS[record.levelname] + message +
                          colorama.Style.RESET_ALL)
        self.stream.write(getattr(self, 'terminator', '\n'))
        self.flush()



from setuptools import setup, find_packages
from logorama import __version__, __package__

setup(
    name=__package__,
    version=__version__,
    description='Light weight colorful python logger',
    author='Kapil Sharma',
    author_email='sharmakapil8@gmail.com',
    packages=find_packages(),
    install_requires=[
        'colorama',
        'pytz'
    ],
    entry_points={
    },
    include_package_data=True,
    zip_safe=False
)